from testcontainers_on_whales.__version__ import __version__
from testcontainers_on_whales.core.container import Container
